#
# spec file for package python-XlsxWriter
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-XlsxWriter
Version:        0.9.6
Release:        lp150.1.4
Summary:        Python module for writing OOXML spreadsheet files
License:        BSD-2-Clause
Group:          Development/Languages/Python
Url:            https://xlsxwriter.readthedocs.org/
Source:         https://files.pythonhosted.org/packages/source/X/XlsxWriter/XlsxWriter-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%ifpython2
# python-xlsxwriter was last used in openSUSE Leap 42.1.
Provides:       %{oldpython}-xlsxwriter = %{version}
Obsoletes:      %{oldpython}-xlsxwriter < %{version}
%endif
%ifpython3
# python3-xlsxwriter was last used in openSUSE Leap 42.1.
Provides:       python3-xlsxwriter = %{version}
Obsoletes:      python3-xlsxwriter < %{version}
%endif

%description
XlsxWriter is a Python module for writing files in the Microsoft
Office Open XML spreadsheet format. It can be used to write text,
numbers, formulas and hyperlinks to multiple worksheets and it
supports features such as formatting and many more.

%python_subpackages

%prep
%setup -q -n XlsxWriter-%{version}

%build
%python_build

%install
%{python_expand %$python_install && \
  mv %{buildroot}%{_bindir}/vba_extract.py \
   %{buildroot}%{_bindir}/vba_extract-%$python_bin_suffix}

%prepare_alternative vba_extract
%fdupes %{buildroot}%{python_sitelib}/

%post
%python_install_alternative vba_extract

%postun
%python_uninstall_alternative vba_extract

%files %{python_files}
%defattr(-,root,root)
%doc Changes LICENSE.txt README.rst
%python_alternative %{_bindir}/vba_extract
%{python_sitelib}/xlsxwriter/
%{python_sitelib}/XlsxWriter-%{version}-py%{python_version}.egg-info

%changelog
* Thu Mar  2 2017 sor.alexei@meowr.ru
- Update to version 0.9.6 (changes since 0.9.3):
  * Add user definable removal of timezones in datetimes
    (gh#jmcnamara/XlsxWriter#257).
  * Fix a duplicate header warning in add_table when there is only
    one user defined header (gh#jmcnamara/XlsxWriter#380).
  * A fix for the center_across property in add_format
    (gh#jmcnamara/XlsxWriter#381).
  * A fix for a missing remove_timezone option in the Chart class
    (gh#jmcnamara/XlsxWriter#404).
  * A fix for a table with data but without a header
    (gh#jmcnamara/XlsxWriter#405>).
  * Add a warning when the number of series in a chart exceeds
    Excel's limit of 255 (gh#jmcnamara/XlsxWriter#399).
- Update for the multipython build.
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Fri Jul 22 2016 sor.alexei@meowr.ru
- Update to version 0.9.3 (changes since 0.8.7):
  * Add workbook :func:`set_custom_property` method to set custom
    document properties.
  * Fix for :func:`insert_image` issue when handling images with
    zero dpi.
  * Add :ref:`trendline properties <chart_series_option_trendline>`:
  ``intercept``, ``display_equation`` and ``display_r_squared``.
  * Documented used of font rotation in chart :ref:`data labels
    <chart_series_option_data_labels>`.
  * Add workbook :func:`set_size` method to set the workbook window
    size.
  * Add check to :func:`add_table` to prevent duplicate header
    names which leads to a corrupt Excel file.
- Fix SLE 11 build.
* Wed May 25 2016 toddrme2178@gmail.com
- Update to 0.8.7
  * Fix for issue when inserting read-only images on Windows.
    Issue `#352 <https://github.com/jmcnamara/XlsxWriter/issues/352>`_.
  * Added :func:`get_worksheet_by_name()` method to allow the retrieval of a
    worksheet from a workbook via its name.
  * Fixed issue where internal file creation and modification dates where in the
    local timezone instead of UTC.
- Switch to pythonhosted URL.
- Rename to python3-XlsxWriter to conform to python packaging guidelines
- Implement update-alternatives
* Thu Apr 28 2016 sor.alexei@meowr.ru
- Update to version 0.8.6 (changes since 0.8.4):
  * Add additional documentation on :ref:`ewx_pandas` and
    :ref:`pandas_examples`.
  * Add fix for :func:`set_center_across` format method.
  * Fix for ``external:`` urls where the target/anchor contains
    spaces.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.8.4 (changes since 0.7.7):
  * Add checks for valid and non-duplicate worksheet table names.
  * Add chart pattern fills, see :ref:`chart_formatting_pattern`
    and :ref:`ex_chart_pattern`.
  * Add additional documentation on :ref:`working_with_formulas`.
  * Add option to set chart tick interval.
  * Add transparency option to solid fill colours in chart areas
    (:ref:`chart_formatting_fill`).
  * Add options to configure chart axis tick placement.
    See :func:`set_x_axis()`.
  * Fix for :func:`write_url` exception when the URL contains two
    ``#`` location/anchors. Note, URLs like this aren't strictly
    valid and cannot be entered manually in Excel.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Update to 0.7.7:
  * Add support for table header formatting and a fix for wrapped
    lines in the header.
* Sat Oct 10 2015 sor.alexei@meowr.ru
- Update to 0.7.6:
  * Add option to allow data validation input messages with the
    'any' validate parameter.
  * Fix url encoding of links to external files and directories.
  * Allow hyperlinks longer than 255 characters when the link and
    anchor are each less than or equal to 255 characters.
  * Add ``hyperlink_base`` document property.
  * Fix for images with negative offsets.
* Sat Jul 18 2015 sor.alexei@meowr.ru
- Initial package.
